
%  plot3dpwp
%  Load and make simple plots of the data from 3dpwp simulation 
%   of hurricane Frances in CBLAST.
%
%  Jim Price, January, 2007, jprice@whoi.edu
%  
%  the data and this program are public domain
% 

close all
clear all
%  Set some default graphics things.
set(0,'DefaultTextFontSize',14)
set(0,'DefaultAxesFontSize',14)
set(0,'DefaultAxesLineWidth',1.2)
set(0,'DefaultLineLineWidth',1.5)

load 3dpwpFrances

%  These data are from the 3dpwp model run for the Frances simulation,
%  stress was computed from HWINDS using the Powell et al (2003) Cd
%  T(y, x, z),  temperature, C;   S is salinity, P is pressure, Pa 
%  y is along track distance, km, x is across track, z is depth, m
%  x = 0 is the hurricane track 
%  U, V are across track and along track velocity components
%  stressx(y, x) and stressy are wind stress, Pa
%  x, y are right handed coordinates; z is depth (pos down)
%  the x interval is 5 km, y interval is 2400 s * Uh = 13.2 km,
%  where Uh is the hurricane translation speed, 5.5 m/s
%  time is in days, 0 = hurricane eye passage over y = 0.


% a map of SST
figure(1)
clf reset
[c1 c2] = contour(x, y, T(:,:,1), [25:0.5:30]);
clabel(c1, c2);
xlabel('across-track, km')
ylabel('along track, km')
title('SST, C')
axis('equal')

%  maps of surface current
figure(2)
clf reset
quiver(x, y, U(:,:,1), V(:,:,1))
xlabel('across track, km')
ylabel('along track, km')
title('surface current')
axis('equal')

speed = sqrt(U(:,:,1).^2 + V(:,:,1).^2);
figure(3)
clf reset
[c1 c2] = contour(x, y, speed, [0:0.1:2.]);
clabel(c1, c2);
xlabel('across track, km')
ylabel('along track, km')
title('surface current speed, m/s')
axis('equal')

% maps of wind stress
figure(4)
clf reset
quiver(x, y, stressx, stressy)
xlabel('across track, km')
ylabel('along track, km')
title('wind stress')
axis('equal')

stress = sqrt(stressx(:,:).^2 + stressy(:,:).^2);
figure(5)
clf reset
[c1 c2] = contour(x, y, stress, [0:1:10]);
clabel(c1, c2);
xlabel('across track, km')
ylabel('along track, km')
title('stress magnitude, Pa')
axis('equal')

%  take a slice at constant x;  this is strictly Eulerian
%   and not quite the same as the EM-APEX float following
%  sampling used in the Sanford et al GRL note.

nc = 51;   %  51 gives the track, x = 0
nc = 62;   %  62 is 55 km to the right
Tyz = T(:,nc,:);
Tyz = squeeze(Tyz)';
figure(6)
clf reset
[c1 c2] = contour(time, -z, Tyz, [10:0.5:30]);
clabel(c1, c2);
xlabel('time, days')
ylabel('depth, m')
axis([-1 3 -300 0])
title('T(t, z) along the track')

%  plot the same Tyz data in the form of profiles
[nz, nt] = size(Tyz);
figure(7)
clf reset
axis([15 30 -300 0])
for j=1:3:nt
    hold on
    plot(Tyz(:,j), -z)
    if j==1; plot(Tyz(:,j), -z, 'r', 'linewidth', 3); end
end
xlabel('temperature, C')
ylabel('depth, m')
grid on





